# **JACLANG JASECI**

### Installation
```bash
pip install -e .
```
### Dependencies for Devs
```bash
pip install jaclang black pre-commit pytest flake8 flake8_import_order flake8_docstrings flake8_comprehensions flake8_bugbear flake8_annotations pep8_naming flake8_simplify mypy pytest
pre-commit install
```
# **REFERENCES**
### [**Jaseci**](./docs/Jaseci.md)
### [**Jaseci**](./docs/Jaseci.md)
### [**Jaseci**](./docs/Jaseci.md)
### [**Jaseci**](./docs/Jaseci.md)